@@ -15,8 +15,9 @@
 #include <functional>
 #include <memory>
 #include <map>
+#include "mcrl2/aterm/protaterm.h"          // IProtectedATerm
 #include "mcrl2/atermpp/aterm_traits.h"
-#include "protaterm.h"          // IProtectedATerm
+
 
 namespace atermpp
 {
