@@ -119,7 +119,7 @@ ATermAppl gsProcSpecEltsToSpec(ATermList SpecElts)
       else
       {
         //ProcInit != NULL
-        gsErrorMsg("parse error: multiple initialisations\n");
+        mCRL2log(error) << "parse error: multiple initialisations" << std::endl;
         return NULL;
       }
     }
@@ -159,7 +159,7 @@ ATermAppl gsProcSpecEltsToSpec(ATermList SpecElts)
   //check whether an initialisation is present
   if (ProcInit == NULL)
   {
-    gsErrorMsg("parse error: missing initialisation\n");
+    mCRL2log(error) << "parse error: missing initialisation" << std::endl;
     return NULL;
   }
   Result = gsMakeProcSpec(
@@ -206,7 +206,7 @@ ATermAppl gsPBESSpecEltsToSpec(ATermList SpecElts)
       else
       {
         //PBEqnSpec != NULL
-        gsErrorMsg("parse error: multiple parameterised boolean equation specifications\n");
+        mCRL2log(error) << "parse error: multiple parameterised boolean equation specifications" << std::endl;
         return NULL;
       }
     }
@@ -219,7 +219,7 @@ ATermAppl gsPBESSpecEltsToSpec(ATermList SpecElts)
       else
       {
         //PBInit != NULL
-        gsErrorMsg("parse error: multiple initialisations\n");
+        mCRL2log(error) << "parse error: multiple initialisations" << std::endl;
         return NULL;
       }
     }
@@ -251,13 +251,13 @@ ATermAppl gsPBESSpecEltsToSpec(ATermList SpecElts)
   //check whether a parameterised boolean equation specification is present
   if (PBEqnSpec == NULL)
   {
-    gsErrorMsg("parse error: missing parameterised boolean equation specification\n");
+    mCRL2log(error) << "parse error: missing parameterised boolean equation specification" << std::endl;
     return NULL;
   }
   //check whether an initialisation is present
   if (PBInit == NULL)
   {
-    gsErrorMsg("parse error: missing initialisation\n");
+    mCRL2log(error) << "parse error: missing initialisation" << std::endl;
     return NULL;
   }
   Result = gsMakePBES(
