@@ -13,11 +13,11 @@
 
 #include <istream>
 #include <vector>
-#include <aterm2.h>
+#include "mcrl2/aterm/aterm2.h"
 
 //Global precondition: the ATerm library has been initialised
 
-ATerm parse_streams(std::vector<std::istream*> &streams, bool print_parse_errors = true);
+aterm::ATerm parse_streams(std::vector<std::istream*> &streams, bool print_parse_errors = true);
 /*Pre: streams contains at least one element
        each element of streams is opened for reading
   Post:the contents of streams is parsed
