@@ -13,7 +13,7 @@
 #define BDD_SIMPLIFIER_H
 
 #include <ctime>
-#include "aterm2.h"
+#include "mcrl2/aterm/aterm2.h"
 
 namespace mcrl2
 {
@@ -22,6 +22,9 @@ namespace data
 namespace detail
 {
 
+// XXX remove
+using namespace aterm;
+
 /** \brief A base class for simplifying binary decision diagrams.
  *
  * \detail
