@@ -63,7 +63,7 @@ void test_data_enumerator()
     atermpp::vector<data_expression_with_variables> values = e.enumerate(x);
     for (atermpp::vector<data_expression_with_variables>::const_iterator i = values.begin(); i != values.end(); ++i)
     {
-      std::cout << mcrl2::core::pp(*i) << " " << mcrl2::data::pp(i->variables()) << std::endl;
+      std::cout << data::pp(*i) << " " << data::pp(i->variables()) << std::endl;
     }
 
     data_expression_with_variables expr(x, atermpp::make_vector(x));
@@ -73,7 +73,7 @@ void test_data_enumerator()
       atermpp::vector<data_expression_with_variables> z = e.enumerate(*i);
       for (atermpp::vector<data_expression_with_variables>::const_iterator j = z.begin(); j != z.end(); ++j)
       {
-        std::cout << mcrl2::core::pp(*j) << " " << mcrl2::data::pp(j->variables()) << std::endl;
+        std::cout << data::pp(*j) << " " << data::pp(j->variables()) << std::endl;
       }
     }
   }
@@ -136,7 +136,7 @@ class A: public data_expression
 
 void f(data_expression d)
 {
-  std::cout << "d = " << mcrl2::core::pp(d) << std::endl;
+  std::cout << "d = " << data::pp(d) << std::endl;
 }
 
 void test2()
@@ -144,7 +144,7 @@ void test2()
   variable n("n", sort_pos::pos());
   A a = n;
   f(a);
-  std::cout << "a = " << mcrl2::core::pp(a) << std::endl;
+  std::cout << "a = " << data::pp(a) << std::endl;
   core::garbage_collect();
 }
 
@@ -200,12 +200,12 @@ void test5()
       data_expression b = datar(greater(*i, three));
       if (b == sort_bool::false_())
       {
-        std::clog << "found solution " << pp(*i) << std::endl;
+        std::clog << "found solution " << data::pp(*i) << std::endl;
         result.push_back(*i);
       }
       else if (b == sort_bool::true_())
       {
-        std::clog << "found non-solution " << pp(*i) << std::endl;
+        std::clog << "found non-solution " << data::pp(*i) << std::endl;
       }
       else
       {
@@ -224,9 +224,9 @@ void test5()
 /// \pre The sort expression s is finite, and s is not a function sort
 atermpp::vector<data::data_expression> value_range(data::sort_expression s, const data::data_specification& data_spec, const data::rewriter& rewr)
 {
-  std::cout << "s = " << core::pp(s) << std::endl;
+  std::cout << "s = " << data::pp(s) << std::endl;
   data::variable v("dummy", s);
-  std::cout << "v = " << core::pp(v) << std::endl;
+  std::cout << "v = " << data::pp(v) << std::endl;
   atermpp::vector<data::data_expression> result;
   data::number_postfix_generator generator("UNIQUE_PREFIX");
   data::data_enumerator<data::number_postfix_generator> e(data_spec, rewr, generator);
@@ -245,7 +245,7 @@ void test6()
   atermpp::vector<data_expression> values = value_range(sort_bool::bool_(), data_spec, rewr);
   for (atermpp::vector<data_expression>::const_iterator i = values.begin(); i != values.end(); ++i)
   {
-    std::cout << mcrl2::core::pp(*i) << std::endl;
+    std::cout << data::pp(*i) << std::endl;
   }
 }
 
