@@ -25,6 +25,7 @@
 #include "mcrl2/data/selection.h"
 #include "mcrl2/lps/nextstate/standard.h"
 #include "mcrl2/lps/specification.h"
+#include "mcrl2/lps/detail/instantiate_global_variables.h"
 
 namespace mcrl2
 {
@@ -36,10 +37,11 @@ namespace lps
 class next_state_generator
 {
   protected:
-    const specification& m_specification;
-    legacy_rewriter m_rewriter;
-    data::enumerator_factory<mcrl2::data::classic_enumerator<> > m_enumerator;
-
+    specification m_specification;
+    data::rewriter::strategy m_rewriter_strategy;
+    mcrl2::data::detail::legacy_rewriter m_rewriter;
+    NextState* m_NextState;
+    
   public:
     /// \brief A type that represents a transition to a 'next' state.
     struct state_type
@@ -61,6 +63,25 @@ class next_state_generator
         : transition(transition_),
           state(state_)
       {}
+
+      /// \brief Returns the i-th component of the state in the internal format.
+      /// \deprecated
+      atermpp::aterm operator[](std::size_t i) const
+      {
+        return atermpp::aterm_appl(reinterpret_cast<ATermAppl>(state))(i);
+      }
+
+      /// \brief Returns the label of the transition.
+      atermpp::aterm_appl label() const
+      {
+        return transition;
+      }
+
+      /// \brief Returns the number of components of the state.
+      std::size_t size() const
+      {
+        return atermpp::term_appl<atermpp::aterm_appl>(reinterpret_cast<ATermAppl>(state)).size();
+      }
     };
 
     /// \brief Iterator that generates all successor states of a given state.
@@ -73,7 +94,7 @@ class next_state_generator
       >
     {
       protected:
-        boost::shared_ptr<NextState> m_next_state;
+        NextState* m_next_state;
         boost::shared_ptr<NextStateGenerator> m_generator;
         state_type m_state;
 
@@ -83,52 +104,33 @@ class next_state_generator
         {}
 
         /// \brief Constructor.
-        iterator(const specification& lps_spec,
-                 mcrl2::data::enumerator_factory<mcrl2::data::classic_enumerator<> >& enumerator
-                )
-          : m_next_state(createNextState(lps_spec, enumerator, false)),
+        iterator(NextState* next)
+          : m_next_state(next),
             m_generator(m_next_state->getNextStates(m_next_state->getInitialState())),
             m_state(0, m_next_state->getInitialState())
-        {
-          if (!lps_spec.process().deadlock_summands().empty())
-          {
-            throw mcrl2::runtime_error("can not generate next states for a process containing deadlock summands");
-          }
-        }
+        { }
 
         /// \brief Constructor.
-        iterator(const specification& lps_spec,
-                 mcrl2::data::enumerator_factory<mcrl2::data::classic_enumerator<> >& enumerator,
-                 const atermpp::aterm& state
-                )
-          : m_next_state(createNextState(lps_spec, enumerator, false)),
+        iterator(NextState* next, const atermpp::aterm& state)
+          : m_next_state(next),
             m_generator(m_next_state->getNextStates(state))
         {
           m_state.state = state;
         }
 
         /// \brief Constructor.
-        iterator(const specification& lps_spec,
-                 mcrl2::data::enumerator_factory<mcrl2::data::classic_enumerator<> >& enumerator,
-                 size_t summand_index
-                )
-          : m_next_state(createNextState(lps_spec, enumerator, false)),
+        iterator(NextState* next, size_t summand_index)
+          : m_next_state(next),
             m_generator(m_next_state->getNextStates(m_next_state->getInitialState(), summand_index)),
             m_state(0, m_next_state->getInitialState())
-        {
-          if (!lps_spec.process().deadlock_summands().empty())
-          {
-            throw mcrl2::runtime_error("can not generate next states for a process containing deadlock summands");
-          }
-        }
+        { }
 
         /// \brief Constructor.
-        iterator(const specification& lps_spec,
-                 mcrl2::data::enumerator_factory<mcrl2::data::classic_enumerator<> >& enumerator,
+        iterator(NextState* next,
                  const atermpp::aterm& state,
                  size_t summand_index
                 )
-          : m_next_state(createNextState(lps_spec, enumerator, false)),
+          : m_next_state(next),
             m_generator(m_next_state->getNextStates(state, summand_index))
         {
           m_state.state = state;
@@ -136,7 +138,7 @@ class next_state_generator
 
         operator bool() const
         {
-          return m_next_state.get() != 0;
+          return m_next_state != 0;
         }
 
       private:
@@ -163,41 +165,61 @@ class next_state_generator
           if (!m_generator->next(&m_state.transition, &m_state.state))
           {
             // empty m_next_state, to signal that there is no next state
-            m_next_state.reset();
+            m_next_state = 0;
           }
         }
     };
 
-    /// \brief Constructor.
-    /// The underlying NextStateGenerator can not handle deadlock summands, therefore an exception
-    /// is thrown if the specification contains deadlock summands.
-    next_state_generator(const specification& lps_spec)
-      : m_specification(lps_spec),
-        m_rewriter(lps_spec.data(), data::used_data_equation_selector(lps_spec.data(), lps::find_function_symbols(lps_spec), lps_spec.global_variables())),
-        m_enumerator(lps_spec.data(), m_rewriter)
+    /// \brief Loads a specification from a file
+    /// \param filename The name of a file containing an mCRL2 specification
+    void load(const std::string& filename)
     {
+      m_specification.load(filename);
+      m_specification.process().deadlock_summands().clear();
+      lps::detail::instantiate_global_variables(m_specification);
+      m_rewriter = mcrl2::data::detail::legacy_rewriter(m_specification.data(), data::used_data_equation_selector(m_specification.data(), lps::find_function_symbols(m_specification), m_specification.global_variables()), m_rewriter_strategy);
+      m_NextState = createNextState(m_specification, m_rewriter, false);
+    }
+
+    /// \brief Constructor
+    /// \param filename The name of a file containing an mCRL2 specification
+    /// \param rewriter_strategy The rewriter strategy used for generating next states
+    next_state_generator(const std::string& filename, data::rewriter::strategy rewriter_strategy = data::rewriter::jitty)
+      : m_rewriter_strategy(rewriter_strategy),
+        m_rewriter(data::data_specification())
+        // m_enumerator(data::data_specification(), m_rewriter)
+    {
+      load(filename);
+    }
+
+    /// \brief Constructor
+    next_state_generator(const specification& lps_spec, data::rewriter::strategy rewriter_strategy = data::rewriter::jitty)
+      : m_specification(lps_spec),
+        m_rewriter_strategy(rewriter_strategy),
+        m_rewriter(lps_spec.data(), data::used_data_equation_selector(lps_spec.data(), lps::find_function_symbols(lps_spec), lps_spec.global_variables()), rewriter_strategy)
+        // m_enumerator(lps_spec.data(), m_rewriter)
+    {
+      m_specification.process().deadlock_summands().clear();
+      lps::detail::instantiate_global_variables(m_specification);
+      m_NextState = createNextState(m_specification, m_rewriter, false);
 #ifdef MCRL2_REWRITE_RULE_SELECTION_DEBUG
 std::clog << "--- rewrite rule selection specification ---\n";
 std::clog << lps::pp(lps_spec) << std::endl;
 std::clog << "--- rewrite rule selection function symbols ---\n";
 std::clog << core::detail::print_pp_set(lps::find_function_symbols(lps_spec)) << std::endl;
 #endif
-      if (!lps_spec.process().deadlock_summands().empty())
-      {
-        throw mcrl2::runtime_error("can not generate next states for a process containing deadlock summands");
-      }
     }
 
     /// \brief Returns an iterator for generating the successors of the initial state.
     iterator begin()
     {
-      return iterator(m_specification, m_enumerator);
+      return iterator(m_NextState);
     }
 
     /// \brief Returns an iterator for generating the successors of the given state.
     iterator begin(const atermpp::aterm& state)
     {
-      return iterator(m_specification, m_enumerator, state);
+      return iterator(m_NextState, state);
     }
 
     /// \brief Returns an iterator for generating the successors of the initial state.
@@ -205,7 +227,7 @@ std::clog << core::detail::print_pp_set(lps::find_function_symbols(lps_spec)) <<
     /// generated.
     iterator begin(size_t summand_index)
     {
-      return iterator(m_specification, m_enumerator, summand_index);
+      return iterator(m_NextState, summand_index);
     }
 
     /// \brief Returns an iterator for generating the successors of the given state.
@@ -213,37 +235,57 @@ std::clog << core::detail::print_pp_set(lps::find_function_symbols(lps_spec)) <<
     /// generated.
     iterator begin(const atermpp::aterm& state, size_t summand_index)
     {
-      return iterator(m_specification, m_enumerator, state, summand_index);
+      return iterator(m_NextState, state, summand_index);
     }
 
     /// \brief Returns the initial state of the specification.
-    // TODO: this function should be const, but cannot because of the createNextState interface
-    atermpp::aterm initial_state()
+    atermpp::aterm initial_state() const
     {
-      NextState* nstate = createNextState(m_specification, m_enumerator, false);
-      atermpp::aterm result = nstate->getInitialState();
-      delete nstate;
-      return result;
+      return  m_NextState->getInitialState();
     }
 
+    /// \brief Returns the i-th component of the state s.
+    data::data_expression state_component(const state_type& s, std::size_t i) const
+    {
+      ATerm t = s[i];
+      return atermpp::aterm_appl(m_rewriter.convert_from(t));
+    }     
+
+    /// \brief Converts a value in next state format to a data expression.
+    data::data_expression aterm2expression(const atermpp::aterm& x) const
+    {
+      ATerm a = x;
+      atermpp::aterm_appl result = m_rewriter.convert_from(a);
+      return result;
+    }     
+
+    /// \brief Converts a data expression to a value in next state format.
+    atermpp::aterm expression2aterm(const data::data_expression& x) const
+    {
+      return m_rewriter.convert_to(x);
+    }     
+
     /// \brief Returns a string representation of the given state.
     std::string print_state(const state_type& state) const
     {
-      atermpp::aterm_appl s(reinterpret_cast<ATermAppl>(state.state));
       std::string result("state(");
-      int index = 0;
-      for (atermpp::aterm_appl::const_iterator i = s.begin(); i != s.end(); ++i)
+      for (unsigned int index = 0; index < state.size(); index++)
       {
-        if (index++ != 0)
+        if (index != 0)
         {
           result.append(", ");
         }
-
-        result.append(core::pp(atermpp::aterm(m_rewriter.translate(static_cast<ATerm>(*i)))));
+        result.append(core::pp(state_component(state, index)));
       }
       result.append(")");
       return result;
     }
+
+    /// \brief Returns the currently loaded specification.
+    const lps::specification& get_specification() const
+    {
+      return m_specification;
+    }
 };
 
 } // namespace lps
