@@ -14,10 +14,9 @@
 
 #include <deque>
 #include "mcrl2/atermpp/set_operations.h"
-#include "mcrl2/core/messaging.h"
+#include "mcrl2/utilities/logger.h"
 
 #include "mcrl2/data/classic_enumerator.h"
-#include "mcrl2/data/enumerator_factory.h"
 
 #include "mcrl2/lps/rewrite.h"
 #include "mcrl2/lps/replace.h"
@@ -28,24 +27,38 @@ namespace mcrl2
 namespace lps
 {
 
+/// \brief Return a set with all finite sorts in data specification s.
+atermpp::set<data::sort_expression> finite_sorts(const data::data_specification& s)
+{
+  data::sort_expression_vector sorts = s.sorts();
+  atermpp::set<data::sort_expression> result;
+
+  for(data::sort_expression_vector::const_iterator i = sorts.begin(); i != sorts.end(); ++i)
+  {
+    if(s.is_certainly_finite(*i))
+    {
+      result.insert(*i);
+    }
+  }
+  return result;
+}
+
 template<typename DataRewriter>
 class suminst_algorithm: public lps::detail::lps_algorithm
 {
 
-    typedef data::classic_enumerator< data::mutable_map_substitution<>, data::rewriter, data::selectors::select_not< false > > enumerator_type;
+    typedef data::classic_enumerator< data::rewriter > enumerator_type;
 
   protected:
-    /// Only instantiate finite sorts
-    bool m_finite_sorts_only;
+    /// Sorts to be instantiated
+    atermpp::set<data::sort_expression> m_sorts;
 
     /// Only instantiate tau summands
     bool m_tau_summands_only;
 
     /// Rewriter
     DataRewriter m_rewriter;
-
-    /// Enumerator factory
-    data::enumerator_factory< enumerator_type > m_enumerator_factory;
+    enumerator_type m_enumerator;
 
     template <typename SummandType, typename Container>
     void instantiate_summand(const SummandType& s, Container& result)
@@ -58,13 +71,16 @@ class suminst_algorithm: public lps::detail::lps_algorithm
       for (atermpp::term_list_iterator< variable > i = s.summation_variables().begin();
            i != s.summation_variables().end(); ++i)
       {
-        if (m_spec.data().is_certainly_finite(i->sort()))
+        if(m_sorts.find(i->sort()) != m_sorts.end())
         {
-          variables.push_front(*i);
-        }
-        else if (!m_finite_sorts_only)
-        {
-          variables.push_back(*i);
+          if (m_spec.data().is_certainly_finite(i->sort()))
+          {
+            variables.push_front(*i);
+          }
+          else
+          {
+            variables.push_back(*i);
+          }
         }
       }
 
@@ -81,11 +97,14 @@ class suminst_algorithm: public lps::detail::lps_algorithm
 
         try
         {
-          core::gsDebugMsg("Enumerating condition: %s\n", data::pp(s.condition()).c_str());
+          mCRL2log(debug, "suminst") << "enumerating condition: " << data::pp(s.condition()) << std::endl;
 
-          for (enumerator_type i(m_enumerator_factory.make(boost::make_iterator_range(variables), s.condition())); i != enumerator_type(); ++i)
+          mcrl2_logger::indent();
+
+          for (enumerator_type::iterator i=m_enumerator.begin(boost::make_iterator_range(variables), s.condition());
+                  i != m_enumerator.end(); ++i)
           {
-            core::gsDebugMsg("substitutions: %s\n", data::print_substitution(*i).c_str());
+            mCRL2log(debug, "suminst") << "substitutions: " << data::print_substitution(*i) << std::endl;
 
             SummandType t(s);
             t.summation_variables() = new_summation_variables;
@@ -94,22 +113,21 @@ class suminst_algorithm: public lps::detail::lps_algorithm
             ++nr_summands;
           }
 
+          mcrl2_logger::unindent();
+
           if (nr_summands == 0)
           {
-            core::gsVerboseMsg("All valuations for the variables in the condition of this summand reduce to false; removing this summand\n");
+            mCRL2log(verbose, "suminst") << "all valuations for the variables in the condition of this summand reduce to false; removing this summand" << std::endl;
           }
-          core::gsVerboseMsg("Replaced with %d summands\n", nr_summands);
+          mCRL2log(verbose, "suminst") << "replaced a summand with " << nr_summands << " summand" << (nr_summands == 1?"":"s") << std::endl;
         }
         catch (mcrl2::runtime_error const& e)
         {
           // If an error occurs in enumerating, remove all summands that
           // have been added to result thus far, and re-add the original.
           // This prevents problems e.g. in case of a sort without constructors.
-          if (core::gsDebug)
-          {
-            std::cerr << "An error occurred in enumeration, removing already added summands, and keeping the original\n";
-            std::cerr << e.what() << "\n";
-          }
+          mCRL2log(debug, "suminst") << "An error occurred in enumeration, removing already added summands, and keeping the original" << std::endl;
+          mCRL2log(debug, "suminst") << e.what() << std::endl;
 
           result.resize(result.size() - nr_summands);
           result.push_back(s);
@@ -120,14 +138,20 @@ class suminst_algorithm: public lps::detail::lps_algorithm
   public:
     suminst_algorithm(specification& spec,
                       DataRewriter& r,
-                      bool finite_sorts_only = true,
+                      atermpp::set<data::sort_expression> sorts = atermpp::set<data::sort_expression>(),
                       bool tau_summands_only = false)
-      : lps_algorithm(spec, core::gsVerbose),
-        m_finite_sorts_only(finite_sorts_only),
+      : lps_algorithm(spec),
+        m_sorts(sorts),
         m_tau_summands_only(tau_summands_only),
         m_rewriter(r),
-        m_enumerator_factory(spec.data(), m_rewriter)
-    {}
+        m_enumerator(spec.data(),r)
+    {
+      if(sorts.empty())
+      {
+        mCRL2log(info, "suminst") << "an empty set of sorts to be unfolded was provided; defaulting to all finite sorts" << std::endl;
+        m_sorts = finite_sorts(spec.data());
+      }
+    }
 
     void run()
     {
