@@ -17,8 +17,8 @@
 #include "mcrl2/data/function_symbol.h"
 #include "mcrl2/atermpp/container_utility.h"
 #include "mcrl2/lps/action.h"
-#include "mcrl2/lps/print.h"
 #include "mcrl2/core/garbage_collection.h"
+#include "mcrl2/core/print.h"
 
 using namespace mcrl2;
 using namespace mcrl2::core;
@@ -28,7 +28,6 @@ using namespace mcrl2::lps;
 int test_main(int argc, char** argv)
 {
   using atermpp::make_vector;
-  using mcrl2::core::pp;
 
   MCRL2_ATERMPP_INIT(argc, argv)
 
@@ -53,8 +52,8 @@ int test_main(int argc, char** argv)
   BOOST_CHECK(!equal_signatures(a1, a3));
 
   action empty = action();
-  std::cerr << pp(empty) << std::endl;
-  std::cerr << pp(action()) << std::endl;
+  std::cerr << core::pp(empty) << std::endl;
+  std::cerr << core::pp(action()) << std::endl;
 
   core::garbage_collect();
 
