@@ -15,6 +15,7 @@
 #include <mcrl2/lps/specification.h>
 #include <mcrl2/lps/binary.h>
 #include <mcrl2/lps/linearise.h>
+#include "mcrl2/lps/detail/test_input.h"
 #include "mcrl2/core/garbage_collection.h"
 #include "mcrl2/atermpp/aterm_init.h"
 
@@ -271,59 +272,18 @@ void test_bug_623()
     data_expression_list next_state = i->next_state(s1.process().process_parameters());
     BOOST_CHECK(next_state.size() == 2);
     BOOST_CHECK(*next_state.begin() != *(++next_state.begin()));
-    std::clog << "erroneous next state " << pp(next_state) << std::endl;
+    std::clog << "erroneous next state " << data::pp(next_state) << std::endl;
   }
 
 }
 
 void test_abp()
 {
-  core::gsDebug = true;
-
-  const std::string ABP_SPEC =
-    "% This file contains the alternating bit protocol, as described in W.J.    \n"
-    "% Fokkink, J.F. Groote and M.A. Reniers, Modelling Reactive Systems.       \n"
-    "%                                                                          \n"
-    "% The only exception is that the domain D consists of two data elements to \n"
-    "% facilitate simulation.                                                   \n"
-    "                                                                           \n"
-    "sort                                                                       \n"
-    "  D     = struct d1 | d2;                                                  \n"
-    "  Error = struct e;                                                        \n"
-    "                                                                           \n"
-    "act                                                                        \n"
-    "  r1,s4: D;                                                                \n"
-    "  s2,r2,c2: D # Bool;                                                      \n"
-    "  s3,r3,c3: D # Bool;                                                      \n"
-    "  s3,r3,c3: Error;                                                         \n"
-    "  s5,r5,c5: Bool;                                                          \n"
-    "  s6,r6,c6: Bool;                                                          \n"
-    "  s6,r6,c6: Error;                                                         \n"
-    "  i;                                                                       \n"
-    "                                                                           \n"
-    "proc                                                                       \n"
-    "  S(b:Bool)     = sum d:D. r1(d).T(d,b);                                   \n"
-    "  T(d:D,b:Bool) = s2(d,b).(r6(b).S(!b)+(r6(!b)+r6(e)).T(d,b));             \n"
-    "                                                                           \n"
-    "  R(b:Bool)     = sum d:D. r3(d,b).s4(d).s5(b).R(!b)+                      \n"
-    "                  (sum d:D.r3(d,!b)+r3(e)).s5(!b).R(b);                    \n"
-    "                                                                           \n"
-    "  K             = sum d:D,b:Bool. r2(d,b).(i.s3(d,b)+i.s3(e)).K;           \n"
-    "                                                                           \n"
-    "  L             = sum b:Bool. r5(b).(i.s6(b)+i.s6(e)).L;                   \n"
-    "                                                                           \n"
-    "init                                                                       \n"
-    "  allow({r1,s4,c2,c3,c5,c6,i},                                             \n"
-    "    comm({r2|s2->c2, r3|s3->c3, r5|s5->c5, r6|s6->c6},                     \n"
-    "        S(true) || K || L || R(true)                                       \n"
-    "    )                                                                      \n"
-    "  );                                                                       \n"
-    ;
-  specification spec = linearise(ABP_SPEC);
-  std::clog << "--- before ---\n" << pp(spec) << std::endl;
+  specification spec = linearise(lps::detail::ABP_SPECIFICATION());
+  std::clog << "--- before ---\n" << lps::pp(spec) << std::endl;
   rewriter r(spec.data());
   binary_algorithm<rewriter>(spec, r).run();
-  std::clog << "--- after ---\n" << pp(spec) << std::endl;
+  std::clog << "--- after ---\n" << lps::pp(spec) << std::endl;
   BOOST_CHECK(is_well_typed(spec));
   core::garbage_collect();
 }
