@@ -19,6 +19,7 @@
 #include "mcrl2/lps/specification.h"
 #include "mcrl2/lps/rewrite.h"
 #include "mcrl2/lps/parse.h"
+#include "mcrl2/lps/print.h"
 #include "mcrl2/core/garbage_collection.h"
 #include "mcrl2/lps/detail/specification_property_map.h"
 #include "mcrl2/atermpp/aterm_init.h"
@@ -170,17 +171,14 @@ void test_lps_rewriter(std::string src_text, std::string dest_text, std::string
   data::rewriter R(src.data());
   data::mutable_map_substitution< > sigma;
   data::detail::parse_substitutions(sigma_text, src.data(), sigma);
-  data::rewriter_adapter<data::rewriter, data::mutable_map_substitution< > > Rsigma(R, sigma);
-  lps::detail::make_lps_rewriter(Rsigma).rewrite(src);
+  lps::rewrite(src, R, sigma);
 
   if (src != dest)
   {
     std::cerr << "--- test failed ---" << std::endl;
-    std::cerr << pp(src.process().action_summands()) << std::endl;
-    std::cerr << pp(src.initial_process()) << std::endl;
+    std::cerr << lps::pp(src) << std::endl;
     std::cerr << "-------------------" << std::endl;
-    std::cerr << pp(dest.process().action_summands()) << std::endl;
-    std::cerr << pp(dest.initial_process()) << std::endl;
+    std::cerr << lps::pp(dest) << std::endl;
   }
   BOOST_CHECK(src == dest);
   core::garbage_collect();
