@@ -13,7 +13,7 @@
 #include <vector>
 #include <map>
 #include "mcrl2/lts/lts.h"
-#include "mcrl2/core/messaging.h"
+#include "mcrl2/utilities/logger.h"
 
 namespace mcrl2
 {
@@ -112,11 +112,9 @@ template < class LTS_TYPE>
 scc_partitioner<LTS_TYPE>::scc_partitioner(LTS_TYPE& l)
   :aut(l)
 {
-  if (core::gsDebug)
-  {
-    std::cerr << "Tau loop (SCC) partitioner created for " << l.num_states() << " states and " <<
-              l.num_transitions() << " transitions\n";
-  }
+  mCRL2log(debug) << "Tau loop (SCC) partitioner created for " << l.num_states() << " states and " <<
+              l.num_transitions() << " transitions" << std::endl;
+
   // read and store tau transitions.
   std::map < state_type, std::vector < state_type > > src_tgt;
   for (transition_const_range r=aut.get_transitions(); !r.empty(); r.advance_begin(1))
@@ -157,10 +155,7 @@ scc_partitioner<LTS_TYPE>::scc_partitioner(LTS_TYPE& l)
       equivalence_class_index++;
     }
   }
-  if (core::gsDebug)
-  {
-    std::cerr << "Tau loop (SCC) partitioner reduces lts to " << equivalence_class_index << " states.\n";
-  }
+  mCRL2log(debug) << "Tau loop (SCC) partitioner reduces lts to " << equivalence_class_index << " states." << std::endl;
 
   dfsn2state.clear();
 }
@@ -277,16 +272,9 @@ template < class LTS_TYPE>
 void scc_reduce(LTS_TYPE& l,const bool preserve_divergence_loops = false)
 {
   detail::scc_partitioner<LTS_TYPE> scc_part(l);
-
-  // Clear this LTS, but keep the labels
-  // l.clear_type();
-  l.clear_states();
-
-  // Set the resulting number of states and transitions.
+  scc_part.replace_transitions(preserve_divergence_loops);
   l.set_num_states(scc_part.num_eq_classes());
   l.set_initial_state(scc_part.get_eq_class(l.initial_state()));
-
-  scc_part.replace_transitions(preserve_divergence_loops);
 }
 
 }
