@@ -13,7 +13,10 @@
 #define LIBLTS_SIM_H
 #include <vector>
 #include <cstdlib>
-#include "mcrl2/core/messaging.h"
+#include <string>
+#include <sstream>
+#include "mcrl2/utilities/logger.h"
+#include "mcrl2/utilities/logger.h"
 #include "mcrl2/exception.h"
 #include "mcrl2/lts/lts.h"
 #include "mcrl2/lts/lts_utilities.h"
@@ -146,13 +149,13 @@ class sim_partitioner
     void initialise_pre_EA();
     void induce_P_on_Pi();
 
-    void print_Sigma_P();
-    void print_Pi_Q();
-    void print_Sigma();
-    void print_Pi();
-    void print_relation(size_t s,std::vector< std::vector<bool> > &R);
-    void print_block(size_t b);
-    void print_structure(hash_table3* struc);
+    std::string print_Sigma_P();
+    std::string print_Pi_Q();
+    std::string print_Sigma();
+    std::string print_Pi();
+    std::string print_relation(size_t s,std::vector< std::vector<bool> > &R);
+    std::string print_block(size_t b);
+    std::string print_structure(hash_table3* struc);
 };
 
 
@@ -179,12 +182,9 @@ void sim_partitioner<LTS_TYPE>::partitioning_algorithm()
   using namespace mcrl2::core;
   initialise_datastructures();
 
-  if (gsDebug)
-  {
-    gsMessage("--------------------- INITIALISATION ---------------------------\n");
-  }
+  mCRL2log(debug) << "--------------------- INITIALISATION ---------------------------" << std::endl;
 
-  gsVerboseMsg("  initialisation; number of blocks: %u\n",s_Sigma);
+  mCRL2log(verbose) << "  initialisation; number of blocks: " << s_Sigma << std::endl;
   bool change;
   size_t i;
 
@@ -206,12 +206,9 @@ void sim_partitioner<LTS_TYPE>::partitioning_algorithm()
      * time. */
     P.swap(Q);
 
-    if (gsDebug)
-    {
-      gsMessage("--------------------- ITERATION %u ----------------------------------\n",i);
-    }
+    mCRL2log(debug) << "--------------------- ITERATION " << i << " ----------------------------------" << std::endl;
 
-    gsVerboseMsg("  iteration %u; number of blocks: %u\n",i,s_Sigma);
+    mCRL2log(verbose) << "  iteration " << i << "; number of blocks: " << s_Sigma << std::endl;
 
     refine(change);
     if (change)
@@ -229,7 +226,8 @@ void sim_partitioner<LTS_TYPE>::partitioning_algorithm()
     }
     ++i;
   }
-  if (gsDebug)
+
+  if (mCRL2logEnabled(debug))
   {
     print_Pi_Q();
   }
@@ -365,9 +363,9 @@ void sim_partitioner<LTS_TYPE>::refine(bool& change)
     parent[alpha] = alpha;
   }
 
-  if (gsDebug)
+  if (mCRL2logEnabled(debug))
   {
-    gsMessage("--------------------- Refine ---------------------------------------\n");
+    mCRL2log(debug) << "--------------------- Refine ---------------------------------------" << std::endl;
     print_Sigma_P();
   }
 
@@ -376,18 +374,18 @@ void sim_partitioner<LTS_TYPE>::refine(bool& change)
   Sort.reserve(s_Sigma);
   reverse_topological_sort(Sort);
 
-  if (gsDebug)
+  if (mCRL2logEnabled(debug))
   {
-    gsMessage("reverse topological sort is: [");
+    mCRL2log(debug) << "reverse topological sort is: [";
     for (size_t i = 0; i < Sort.size(); ++i)
     {
-      gsMessage("%u",Sort[i]);
+      mCRL2log(debug) << Sort[i];
       if (i+1 < Sort.size())
       {
-        gsMessage(",");
+        mCRL2log(debug) << ",";
       }
     }
-    gsMessage("]\n");
+    mCRL2log(debug) << "]" << std::endl;
   }
 
   /* Some local variables */
@@ -400,11 +398,8 @@ void sim_partitioner<LTS_TYPE>::refine(bool& change)
   /* The main loop */
   for (l = 0; l < aut.num_action_labels(); ++l)
   {
-    if (gsDebug)
-    {
-      gsMessage("---------------------------------------------------\n");
-      gsMessage("Label = \"%s\"\n", mcrl2::lts::detail::pp(aut.action_label(l)).c_str());
-    }
+    mCRL2log(debug) << "---------------------------------------------------" << std::endl;
+    mCRL2log(debug) << "Label = \"" << mcrl2::lts::detail::pp(aut.action_label(l)) << "\"" << std::endl;
 
     /* reset the stable function */
     stable.assign(s_Pi,v_false);
@@ -557,10 +552,7 @@ template <class LTS_TYPE>
 void sim_partitioner<LTS_TYPE>::update()
 {
   using namespace mcrl2::core;
-  if (gsDebug)
-  {
-    gsMessage("--------------------- Update ---------------------------------------\n");
-  }
+  mCRL2log(debug) << "--------------------- Update ---------------------------------------" << std::endl;
 
   size_t l,alpha,gamma;
   std::vector<size_t>::iterator alphai, last;
@@ -596,14 +588,14 @@ void sim_partitioner<LTS_TYPE>::update()
     }
   }
 
-  if (gsDebug)
+  if (mCRL2logEnabled(debug))
   {
-    gsMessage("------ Filter(false) ------\nExists: ");
-    print_structure(exists);
-    gsMessage("\nForall: ");
-    print_structure(forall);
-    gsMessage("\nSimulation relation: ");
-    print_relation(s_Pi,Q);
+    mCRL2log(debug) << "------ Filter(false) ------\nExists: ";
+    mCRL2log(debug) << print_structure(exists);
+    mCRL2log(debug) << "\nForall: ";
+    mCRL2log(debug) << print_structure(forall);
+    mCRL2log(debug) << "\nSimulation relation: ";
+    mCRL2log(debug) << print_relation(s_Pi,Q);
   }
 
   /* Apply the first filtering to Q */
@@ -638,14 +630,14 @@ void sim_partitioner<LTS_TYPE>::update()
       pre_forall[l].push_back(forall->get_num_elements());
     }
   }
-  if (gsDebug)
+  if (mCRL2logEnabled(debug))
   {
-    gsMessage("------ Filter(true) ------\nExists: ");
-    print_structure(exists);
-    gsMessage("\nForall: ");
-    print_structure(forall);
-    gsMessage("\nSimulation relation: ");
-    print_relation(s_Pi,Q);
+    mCRL2log(debug) << "------ Filter(true) ------\nExists: ";
+    mCRL2log(debug) << print_structure(exists);
+    mCRL2log(debug) << "\nForall: ";
+    mCRL2log(debug) << print_structure(forall);
+    mCRL2log(debug) << "\nSimulation relation: ";
+    mCRL2log(debug) << print_relation(s_Pi,Q);
   }
 
   /* Apply the second filtering to Q */
@@ -989,72 +981,77 @@ void sim_partitione<LTS_TYPE>r::update_nfa()
 /* ----------------- FOR DEBUGGING ---------------------------------- */
 
 template <class LTS_TYPE>
-void sim_partitioner<LTS_TYPE>::print_Sigma_P()
+std::string sim_partitioner<LTS_TYPE>::print_Sigma_P()
 {
   using namespace mcrl2::core;
-  print_Sigma();
-  gsMessage("Simulation relation: ");
-  print_relation(s_Sigma,P);
+  std::stringstream result;
+  result << print_Sigma() << "Simulation relation: " << print_relation(s_Sigma,P);
+  return result.str();
 }
 
 template <class LTS_TYPE>
-void sim_partitioner<LTS_TYPE>::print_Pi_Q()
+std::string sim_partitioner<LTS_TYPE>::print_Pi_Q()
 {
   using namespace mcrl2::core;
-  print_Pi();
-  gsMessage("Simulation relation: ");
-  print_relation(s_Pi,Q);
+  std::stringstream result;
+  result << print_Pi() << "Simulation relation: " << print_relation(s_Pi,Q);
+  return result.str();
 }
 
 template <class LTS_TYPE>
-void sim_partitioner<LTS_TYPE>::print_Sigma()
+std::string sim_partitioner<LTS_TYPE>::print_Sigma()
 {
   using namespace mcrl2::core;
+  std::stringstream result;
   std::vector<size_t>::iterator ci, last;
   for (size_t b = 0; b < s_Sigma; ++b)
   {
-    gsMessage("block %u: {",b);
+    result << "block " << b << ": {";
     last = children[b].end();
     for (ci = children[b].begin(); ci != last; ++ci)
     {
-      print_block(*ci);
+      result << print_block(*ci);
     }
-    gsMessage("}\n");
+    result << "}" << std::endl;
   }
+  return result.str();
 }
 
 template <class LTS_TYPE>
-void sim_partitioner<LTS_TYPE>::print_Pi()
+std::string sim_partitioner<LTS_TYPE>::print_Pi()
 {
+  std::stringstream result;
   using namespace mcrl2::core;
   for (size_t b = 0; b < s_Pi; ++b)
   {
-    gsMessage("block %u: {",b);
-    print_block(b);
-    gsMessage("}\n");
+    result << "block " << b << ": {" << print_block(b) << "}" << std::endl;
   }
+  return result.str();
 }
 
 template <class LTS_TYPE>
-void sim_partitioner<LTS_TYPE>::print_block(size_t b)
+std::string sim_partitioner<LTS_TYPE>::print_block(size_t b)
 {
+  std::stringstream result;
   using namespace mcrl2::core;
   for (ptrdiff_t i = contents_u[b]; i != LIST_END; i = state_buckets[i].next)
   {
-    gsMessage("%d,",i);
+    result << i << ",";
   }
   for (ptrdiff_t i = contents_t[b]; i != LIST_END; i = state_buckets[i].next)
   {
-    gsMessage("%d,",i);
+    result << i << ",";
   }
+  return result.str();
 }
 
 template <class LTS_TYPE>
-void sim_partitioner<LTS_TYPE>::print_relation(size_t s,
+std::string sim_partitioner<LTS_TYPE>::print_relation(size_t s,
     std::vector< std::vector<bool> > &R)
 {
   using namespace mcrl2::core;
-  gsMessage("{");
+  std::stringstream result;
+  result << "{";
   size_t beta,gamma;
   for (beta = 0; beta < s; ++beta)
   {
@@ -1062,26 +1059,28 @@ void sim_partitioner<LTS_TYPE>::print_relation(size_t s,
     {
       if (R[beta][gamma])
       {
-        gsMessage("(%u,%u),",beta,gamma);
+        result << "(" << beta << "," << gamma << "),";
       }
     }
   }
-  gsMessage("}\n");
+  result << "}" << std::endl;
+  return result.str();
 }
 
 template <class LTS_TYPE>
-void sim_partitioner<LTS_TYPE>::print_structure(hash_table3* struc)
+std::string sim_partitioner<LTS_TYPE>::print_structure(hash_table3* struc)
 {
   using namespace mcrl2::core;
-  gsMessage("{");
+  std::stringstream result;
+  result << "{";
   hash_table3_iterator i(struc);
   for (; !i.is_end(); ++i)
   {
-    gsMessage("(%u,%s,%u),", i.get_x(),
-              mcrl2::lts::detail::pp(aut.action_label(i.get_y())).c_str(),
-              i.get_z());
+    result << "(" << i.get_x() << "," << mcrl2::lts::detail::pp(aut.action_label(i.get_y()))
+           << "," << i.get_z() << "),";
   }
-  gsMessage("}");
+  result << "}";
+  return result.str();
 }
 
 } // namespace detail
