@@ -28,7 +28,7 @@
 
 #include "boost/iterator/transform_iterator.hpp"
 
-#include "aterm2.h"
+#include "mcrl2/aterm/aterm2.h"
 #include "mcrl2/atermpp/set.h"
 #include "mcrl2/atermpp/vector.h"
 #include "mcrl2/atermpp/container_utility.h"
