@@ -25,30 +25,6 @@
 #include "mcrl2/data/set_identifier_generator.h"
 #include "mcrl2/data/replace.h"
 
-namespace atermpp
-{
-/// \cond INTERNAL_DOCS
-template<>
-struct aterm_traits<std::pair<mcrl2::data::variable, mcrl2::data::variable> >
-{
-  static void protect(const std::pair<mcrl2::data::variable, mcrl2::data::variable>& t)
-  {
-    t.first.protect();
-    t.second.protect();
-  }
-  static void unprotect(const std::pair<mcrl2::data::variable, mcrl2::data::variable>& t)
-  {
-    t.first.unprotect();
-    t.second.unprotect();
-  }
-  static void mark(const std::pair<mcrl2::data::variable, mcrl2::data::variable>& t)
-  {
-    t.first.mark();
-    t.second.mark();
-  }
-};
-} // namespace atermpp
-
 namespace mcrl2
 {
 
