@@ -14,7 +14,7 @@
 #include <string>
 #include <boost/foreach.hpp>
 #include <boost/test/minimal.hpp>
-#include "mcrl2/core/messaging.h"
+#include "mcrl2/utilities/logger.h"
 #include "mcrl2/pbes/constelm.h"
 #include "mcrl2/pbes/rewriter.h"
 #include "mcrl2/pbes/txt2pbes.h"
