@@ -46,11 +46,6 @@ class rewriter_tool: public Tool
         "  'jittyp' for jitty rewriting with prover,\n"
 #ifdef MCRL2_JITTYC_AVAILABLE
         "  'jittyc' for compiled jitty rewriting,\n"
-#endif
-        "  'inner' for innermost rewriting,\n"
-        "  'innerp' for innermost rewriting with prover, or\n"
-#ifdef MCRL2_INNERC_AVAILABLE
-        "  'innerc' for compiled innermost rewriting"
 #endif
         ,'r'
       );
