@@ -11,11 +11,11 @@
 #define MCRL2_CHI2LEXER_H
 
 #include <istream>
-#include <aterm2.h>
+#include "mcrl2/aterm/aterm2.h"
 
 //Global precondition: the ATerm library has been initialised
 
-ATermAppl parse_stream(std::istream& streams);
+aterm::ATermAppl parse_stream(std::istream& streams);
 /*Pre: streams contains at least one element
        each element of streams is opened for reading
   Post:the contents of streams is parsed
