@@ -831,15 +831,15 @@ void fourier_motzkin(const std::vector < linear_inequality > &inequalities_in,
                      const rewriter& r)
 {
   assert(resulting_inequalities.empty());
-  if (core::gsDebug)
+  if (mCRL2logEnabled(debug))
   {
-    std::cerr << "Starting Fourier-Motzkin elimination on " + pp_vector(inequalities_in) + " on variables ";
+    mCRL2log(debug) << "Starting Fourier-Motzkin elimination on " + pp_vector(inequalities_in) + " on variables ";
     for (Data_variable_iterator i=variables_begin;
          i!=variables_end; ++i)
     {
-      std::cerr << " " << pp(*i) ;
+      mCRL2log(debug) << " " << pp(*i) ;
     }
-    std::cerr << "\n";
+    mCRL2log(debug) << std::endl;
   }
 
   std::vector < linear_inequality > inequalities;
@@ -962,10 +962,6 @@ void fourier_motzkin(const std::vector < linear_inequality > &inequalities_in,
         if (e.is_false(r))
         {
           resulting_inequalities.push_back(linear_inequality()); // This is a single contraditory inequality;
-          if (core::gsDebug)
-          {
-            std::cerr << "Fourier-Motzkin elimination yields " + pp_vector(resulting_inequalities) + "\n";
-          }
           return;
         }
         if (!e.is_true(r))
@@ -988,10 +984,7 @@ void fourier_motzkin(const std::vector < linear_inequality > &inequalities_in,
       resulting_inequalities.push_back(*i);
     }
   }
-  if (core::gsDebug)
-  {
-    std::cerr << "Fourier-Motzkin elimination yields " + pp_vector(resulting_inequalities) + "\n";
-  }
+  mCRL2log(debug) << "Fourier-Motzkin elimination yields " << pp_vector(resulting_inequalities) << std::endl;
 }
 
 
@@ -1247,7 +1240,7 @@ static void pivot_and_update(
   }
 
   // std::cerr << "End pivoting " << pp(xj) << "\n";
-  if (core::gsDebug)
+  if (mCRL2logEnabled(debug))
   {
     for (atermpp::map < variable,data_expression >::const_iterator i=beta.begin();
          i!=beta.end(); ++i)
@@ -1290,10 +1283,7 @@ inline bool is_inconsistent(
   // First remove all equalities by Gauss elimination and make a fresh variable
   // generator.
 
-  if (core::gsDebug)
-  {
-    std::cerr << "Starting an inconsistency check on " + pp_vector(inequalities_in) << "\n";
-  }
+  mCRL2log(debug) << "Starting an inconsistency check on " + pp_vector(inequalities_in) << "\n";
 
   // The required data structures
   atermpp::map < variable,data_expression > lowerbounds;
@@ -1313,10 +1303,7 @@ inline bool is_inconsistent(
   {
     if (i->is_false(r))
     {
-      if (core::gsDebug)
-      {
-        std::cerr << "Inconsistent, because linear inequalities contains an inconsistent inequality\n";
-      }
+      mCRL2log(debug) << "Inconsistent, because linear inequalities contains an inconsistent inequality\n";
       return true;
     }
     i->add_variables(non_basic_variables);
@@ -1354,10 +1341,7 @@ inline bool is_inconsistent(
   {
     if (i->is_false(r))
     {
-      if (core::gsDebug)
-      {
-        std::cerr << "Inconsistent, because linear inequalities contains an inconsistent inequality after gaus elimination\n";
-      }
+      mCRL2log(debug) << "Inconsistent, because linear inequalities contains an inconsistent inequality after gaus elimination\n";
       return true;
     }
     if (!i->is_true(r))  // This inequality is redundant and can be skipped.
@@ -1441,10 +1425,7 @@ inline bool is_inconsistent(
            ((upperbounds[*i]==lowerbounds[*i]) &&
             (rewrite_with_memory(less(upperbounds_delta_correction[*i],lowerbounds_delta_correction[*i]),r)==sort_bool::true_()))))
       {
-        if (core::gsDebug)
-        {
-          std::cerr << "Inconsistent, preprocessing " << pp(*i) << "\n";
-        }
+        mCRL2log(debug) << "Inconsistent, preprocessing " << pp(*i) << "\n";
         return true; // Inconsistent.
       }
       beta[*i]=lowerbounds[*i];
@@ -1524,9 +1505,9 @@ inline bool is_inconsistent(
     if (!found)
     {
       // The in_equalities are consistent. Return false.
-      if (core::gsDebug)
+      if (mCRL2logEnabled(debug))
       {
-        std::cerr << "Consistent while pivoting\n";
+        mCRL2log(debug) << "Consistent while pivoting\n";
         /* for(atermpp::map < variable,data_expression >::const_iterator i=lowerbounds.begin();
                       i!=lowerbounds.end(); ++i)
         { variable v=i->first;
@@ -1590,10 +1571,7 @@ inline bool is_inconsistent(
       if (!found)
       {
         // The inequalities are inconsistent.
-        if (core::gsDebug)
-        {
-          std::cerr << "Inconsistent while pivoting\n";
-        }
+        mCRL2log(debug) << "Inconsistent while pivoting\n";
         return true;
       }
 
@@ -1628,10 +1606,7 @@ inline bool is_inconsistent(
       if (!found)
       {
         // The inequalities are inconsistent.
-        if (core::gsDebug)
-        {
-          std::cerr << "Inconsistent while pivoting (1)\n";
-        }
+        mCRL2log(debug) << "Inconsistent while pivoting (1)\n";
         return true;
       }
     }
@@ -1668,8 +1643,6 @@ atermpp::set < variable >  gauss_elimination(
   Variable_iterator variables_end,
   const rewriter& r)
 {
-  // gsDebugMsg("Trying to eliminate variables %P from system %P using gauss elimination\n", (ATermList)variables, (ATermList)inequalities);
-
   atermpp::set < variable >  remaining_variables;
 
   // First copy equalities to the resulting_equalities and the inequalites to resulting_inequalities.
@@ -1823,9 +1796,6 @@ atermpp::set < variable >  gauss_elimination(
     remaining_variables.insert(*i);
   }
 
-  // gsDebugMsg("Gauss elimination eliminated variables %P, resulting in the system %P\n",
-  //                       (ATermList)eliminated_variables, (ATermList)inequalities);
-
   return remaining_variables;
 }
 
