@@ -40,8 +40,8 @@
 #define __simbase_H__
 
 #include <list>
-#include "aterm2.h"
-#include "mcrl2/lps/nextstate.h"
+#include "mcrl2/aterm/aterm2.h"
+#include "mcrl2/lps/nextstate/standard.h"
 
 class SimulatorInterface;
 class SimulatorViewInterface;
