@@ -18,17 +18,17 @@
 #include <cstdlib>
 #include <cstring>
 #include <cassert>
-#include <aterm2.h>
+#include "mcrl2/aterm/aterm2.h"
+#include "mcrl2/aterm/aterm_ext.h"
 #include "lpstrans.h"
-#include "mcrl2/core/messaging.h"
-#include "mcrl2/core/aterm_ext.h"
+#include "mcrl2/utilities/logger.h"
 #include "mcrl2/utilities/input_output_tool.h"
 #include "mcrl2/utilities/mcrl2_gui_tool.h"
 #include "mcrl2/exception.h"
 
 using namespace mcrl2::utilities;
 using namespace mcrl2::utilities::tools;
-using namespace mcrl2::core;
+using namespace aterm;
 
 class tbf2lps_tool: public input_output_tool
 {
@@ -58,7 +58,7 @@ class tbf2lps_tool: public input_output_tool
 
       if (input_filename().empty())
       {
-        gsVerboseMsg("reading mCRL LPS from stdin...\n");
+        mCRL2log(verbose) << "reading mCRL LPS from stdin..." << std::endl;
 
         mcrl_spec = (ATermAppl) ATreadFromFile(stdin);
 
@@ -73,7 +73,7 @@ class tbf2lps_tool: public input_output_tool
       }
       else
       {
-        gsVerboseMsg("reading mCRL LPS from '%s'...\n", input_filename().c_str());
+        mCRL2log(verbose) << "reading mCRL LPS from '" <<  input_filename() << "'..." << std::endl;
 
         FILE* in_stream = fopen(input_filename().c_str(), "rb");
 
@@ -104,13 +104,13 @@ class tbf2lps_tool: public input_output_tool
 
       if (output_filename().empty())
       {
-        gsVerboseMsg("writing mCRL2 LPS to stdout...\n");
+        mCRL2log(verbose) << "writing mCRL2 LPS to stdout..." << std::endl;
 
         ATwriteToSAFFile((ATerm) spec, stdout);
       }
       else
       {
-        gsVerboseMsg("writing mCRL2 LPS to '%s'...\n", output_filename().c_str());
+        mCRL2log(verbose) << "writing mCRL2 LPS to '" <<  output_filename() << "'..." << std::endl;
 
         FILE* outstream = fopen(output_filename().c_str(), "wb");
 
